from ...utils.abbreviated_enum import AbbreviatedEnum


class ManholeUse(AbbreviatedEnum):
    combined = ("Combined", "CB")
    dam = ("Dam", "DP")
    force_main = ("Force Main", "FM")
    levee_gravity = ("Levee Gravity", "LG")
    levee_pressure = ("Levee Pressure", "LP")
    processes = ("Processes", "PR")
    sanitary = ("Sanitary", "SS")
    stormwater = ("Stormwater", "SW")
    not_known = ("Not Known", "XX")
    other = ("Other", "ZZ")
